<?php
/**
 * The header for our theme.
 *
 * Displays all of the <head> section and everything up till <div id="content">
 *
 * @package Accesspress Basic
 */
?><!DOCTYPE html>
<?php
    global $apbasic_options;
    $old_setting = get_option('apbasic_options', $apbasic_options);
    $apbasic_settings = wp_parse_args($old_setting, $apbasic_options);
    $slider_type = $apbasic_settings['slider_type'];
    if ( is_array( $apbasic_settings ) && ! empty( $apbasic_settings )) {
        extract($apbasic_settings);
    }
    
    $site_class = null;
    if($site_layout == 'boxed'){
        $site_class = 'boxed-layout';
    }

    $header_class = '';
    switch($show_header){
        case 'header_logo_only' :
            $header_class = 'header-logo-only';
            break;
        case 'header_text_only' :
            $header_class = 'header-text-only';
            break;
        case 'show_both' :
            $header_class = 'header-text-logo';
            break;
    }
?>
<html <?php language_attributes(); ?>>
<head>
<meta charset="<?php bloginfo( 'charset' ); ?>">
<meta name="viewport" content="width=device-width, initial-scale=1">
<link rel="profile" href="http://gmpg.org/xfn/11">
<link rel="pingback" href="<?php bloginfo( 'pingback_url' ); ?>">
<?php if(!empty($favicon)) : ?>
    <?php if($activate_favicon == 1) : ?>
        <link rel="icon" type="image/png" href="<?php echo esc_url($favicon); ?>">
    <?php endif; ?>
<?php endif; ?>
<?php wp_head(); ?>
</head>

<body <?php body_class($site_class); ?>>
<div id="page" class="hfeed site">
	<a class="skip-link screen-reader-text" href="#content"><?php _e( 'Skip to content', 'accesspress-basic' ); ?></a>

	<header id="masthead" class="site-header <?php echo $header_class; ?>" role="banner">
        	<div class="top-header clearfix">
                <div class="ap-container">
                    <div class="site-branding">
                        <?php if($show_header != 'disable') : ?>
                            
                            <?php if($show_header == 'header_logo_only') : ?>
                                <?php if(get_header_image()) : ?>
                                    <div class="header-logo-container">
                                        <h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><img src="<?php echo header_image(); ?>" /></a></h1>
                                    </div>
                                <?php endif; ?>
                            <?php elseif($show_header == 'header_text_only') : ?>
                                <div class="header-text-container">
                        			<h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
                        			<h2 class="site-description"><?php bloginfo( 'description' ); ?></h2>
                                </div>
                            <?php else : ?>
                                <?php if(get_header_image()) : ?>
                                    <div class="header-logo-container">
                                        <h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><img src="<?php echo $header_logo; ?>" /></a></h1>
                                    </div>
                                <?php endif; ?>
                                <div class="header-text-container">
                        			<h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
                        			<h2 class="site-description"><?php bloginfo( 'description' ); ?></h2>
                                </div>
                            <?php endif; ?>
                            
                        <?php endif; ?>
            		</div><!-- .site-branding -->
                    <div class="right-top-head">
                        <?php if(is_active_sidebar('apbasic_header_text')) : ?>
                            <div class="call-us"><?php dynamic_sidebar('apbasic_header_text'); ?></div>
                        <?php else : ?>
                            <?php if(!empty($header_text)) : ?>
                                <div class="call-us"><?php echo esc_attr($header_text); ?></div>
                            <?php endif; ?>
                        <?php endif; ?>
                        <?php if($show_social_links == 1 && is_active_sidebar('apbasic_header_social_links')) : ?>
                        <div class="social-icons-head">
                            <div class="social-container">
                                <?php dynamic_sidebar('apbasic_header_social_links'); ?>
                            </div>
                        </div>
                        <?php endif; ?>
                    </div>
                </div> <!-- ap-container -->
            </div> <!-- top-header -->
            
            <div class="menu-wrapper clearfix"> 
                <div class="ap-container">
                    <a class="menu-trigger"><span></span><span></span><span></span></a>   
            		<nav id="site-navigation" class="main-navigation" role="navigation">
            			<button class="menu-toggle hide" aria-controls="primary-menu" aria-expanded="false"><?php _e( 'Primary Menu', 'accesspress-basic' ); ?></button>
            			<?php wp_nav_menu( array( 'theme_location' => 'primary', 'menu_id' => 'primary-menu' ) ); ?>
            		</nav><!-- #site-navigation -->
                    <?php if($show_search == 1) : ?>
                        <div class="search-icon">
                        <i class="fa fa-search"></i>
                        <div class="ak-search">
                            <div class="close">&times;</div>
                                 <form action="<?php echo site_url(); ?>" class="search-form" method="get" role="search">
                                    <label>
                                        <span class="screen-reader-text"><?php _e('Search for:', 'accesspress-basic'); ?></span>
                                        <input type="search" title="Search for:" name="s" value="" placeholder="<?php _e('Search content...', 'accesspress-basic'); ?>" class="search-field">
                                    </label>
                                    <input type="submit" value="<?php _e('Search', 'accesspress-basic'); ?>" class="search-submit">
                                 </form>
                         <div class="overlay-search"> </div> 
                        </div>
                    </div> 
                <?php endif; ?>
                </div>
            </div>
            <nav id="site-navigation-responsive" class="main-navigation-responsive">
    			<button class="menu-toggle hide" aria-controls="primary-menu" aria-expanded="false"><?php _e( 'Primary Menu', 'accesspress-basic' ); ?></button>
    			<?php wp_nav_menu( array( 'theme_location' => 'primary', 'menu_id' => 'primary-menu' ) ); ?>
    		</nav><!-- #site-navigation -->
	</header><!-- #masthead -->

	<div id="content" class="site-content <?php echo $slider_type.'-slider'; ?>">
    <?php
        if($show_slider == 'yes') :
            if($show_slider_in_post == 1) :
                 if(is_front_page() || is_single()) :
                 ?>
                <div class="ap-basic-slider-wrapper">
                <?php if($slider_type == 'default') : ?>
                <div class="ap-container">
                <?php endif; ?>
                 <?php 
                    do_action('accesspress_basic_slider');
                ?>
                <?php if($slider_type == 'default') : ?>
                </div>
                <?php endif; ?>
                </div>
                <?php
                 endif;
            else:
                if(is_front_page()) :
                ?>
                <div class="ap-basic-slider-wrapper">
                <?php if($slider_type == 'default') : ?>
                <div class="ap-container">
                <?php endif; ?>
                <?php
                    do_action('accesspress_basic_slider');
                ?>
                <?php if($slider_type == 'default') : ?>
                </div>
                <?php endif; ?>
                </div>
                <?php
                endif;
            endif;
        endif;
    ?>